@@ -909,6 +909,11 @@ WritePCB (FILE * FP)
     WriteLayerData (FP, i, &(PCB->Data->Layer[i]));
   WritePCBNetlistData (FP);
 
+  if (ferror (FP))
+    Message (_("Error writing PCB file\n"));
+  else
+    Message (_("PCB file saved\n"));
+
   return (STATUS_OK);
 }
 
@@ -927,7 +932,12 @@ WritePCBFile (char *Filename)
       return (STATUS_ERROR);
     }
   result = WritePCB (fp);
+
+  if (ferror (fp))
+    Message (_("Error writing PCB backup file %s\n"), Filename);
+
   fclose (fp);
+  Message (_("PCB backup file %s saved\n"), Filename);
   return (result);
 }
 
